import { useQueries } from "@tanstack/react-query";
import styles from "../../../styles";
import {
  EquipmentsAPI,
  EquipmentInstancesAPI,
  UserAPI,
  TransactionsAPI,
} from "../../API/API";
import moment from "moment";

export default function TechnicianWidgets() {
  const todayStartOfDay = moment().startOf("day").format("MM-DD-YYYY hh:mm A");
  const todayEndOfDay = moment().endOf("day").format("MM-DD-YYYY hh:mm A");
  const thisMonthStart = moment().startOf("month").format("MM-DD-YYYY hh:mm A");
  const thisMonthEnd = moment().endOf("month").format("MM-DD-YYYY hh:mm A");
  const queries = useQueries({
    queries: [
      {
        queryKey: ["equipments"],
        queryFn: EquipmentsAPI,
      },
      {
        queryKey: ["equipment_instances"],
        queryFn: EquipmentInstancesAPI,
      },
      {
        queryKey: ["user"],
        queryFn: UserAPI,
      },
      {
        queryKey: ["transactions"],
        queryFn: TransactionsAPI,
      },
    ],
  });
  return (
    <div style={styles.flex_column}>
      <div
        style={{
          ...styles.flex_row,
          ...{
            alignSelf: "center",
            justifyContent: "center",
            flexWrap: "wrap",
          },
        }}
      >
        <div
          style={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
            gap: "24px",
            width: "100%",
            maxWidth: "800px",
          }}
        >
          <p
            style={{
              overflow: "hidden",
              color: "#0E410D",
              fontSize: "24px",
              fontWeight: 700,
              display: "-webkit-box",
              width: "100%",
              maxWidth: "807px",
              flex: 1,
              textAlign: "left",
              marginLeft: "1rem",
              marginBottom: -15,
            }}
          >
            Summary
          </p>
        </div>
        {/* Blue Capsule */}
        <div
          className="capsule"
          style={{
            background: "#DDEDF3",
            margin: 30,
            paddingTop: 50,
          }}
        >
          <div
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              gap: "15px",
            }}
          >
            {/* Transactions all */}
            <div
              style={{
                display: "flex",
                width: "202px",
                height: "245px",
                padding: "25px 10px",
                flexDirection: "column",
                justifyContent: "space-between",
                alignItems: "center",
                borderRadius: "15px",
                background: "#FFF",
                boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
              }}
            >
              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_normal,
                  fontWeight: "400",
                }}
              >
                Total Transactions Today
              </p>

              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_L,
                  margin: 0,
                }}
              >
                {queries[3].data?.filter((transaction) =>
                  moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
                    todayStartOfDay,
                    todayEndOfDay
                  )
                ).length || "0"}
              </p>
              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_normal,
                  fontWeight: "400",
                }}
              >
                Total Transactions this Month
              </p>

              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_L,
                  margin: 0,
                }}
              >
                {queries[3].data?.filter((transaction) =>
                  moment(transaction.timestamp, "MM-DD-YYYY hh:mm A").isBetween(
                    thisMonthStart,
                    thisMonthEnd
                  )
                ).length || "Loading..."}
              </p>
            </div>
            <div
              style={{
                display: "flex",
                width: "40%",
                flexDirection: "column",
                justifyContent: "center",
                alignItems: "center",
                gap: "15px",
                alignSelf: "stretch",
              }}
            >
              <div
                style={{
                  display: "flex",
                  height: "88px",
                  width: "100%",
                  flexDirection: "column",
                  justifyContent: "center",
                  alignItems: "center",
                  alignSelf: "stretch",
                  borderRadius: "15px",
                  background: "#FFF",
                  boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
                }}
              >
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: "0",
                  }}
                >
                  {queries[3].data?.filter(
                    (transaction) =>
                      transaction.transaction_status == "Approved"
                  ).length || 0}
                </p>
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                  }}
                >
                  Pending Request
                </p>
              </div>
              <div
                style={{
                  display: "flex",
                  height: "88px",
                  width: "100%",
                  flexDirection: "column",
                  justifyContent: "center",
                  alignItems: "center",
                  alignSelf: "stretch",
                  borderRadius: "15px",
                  background: "#FFF",
                  boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
                }}
              >
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: "0",
                  }}
                >
                  {queries[3].data?.filter(
                    (transaction) =>
                      transaction.transaction_status == "Borrowed"
                  ).length || 0}
                </p>
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                  }}
                >
                  On Borrow
                </p>
              </div>
              <div
                style={{
                  display: "flex",
                  height: "88px",
                  width: "100%",
                  flexDirection: "column",
                  justifyContent: "center",
                  alignItems: "center",
                  alignSelf: "stretch",
                  borderRadius: "15px",
                  background: "#FFF",
                  boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
                }}
              >
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: "0",
                  }}
                >
                  {queries[3].data?.filter(
                    (transaction) =>
                      transaction.transaction_status == "Finalized"
                  ).length || 0}
                </p>
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                  }}
                >
                  Success
                </p>
              </div>
            </div>
          </div>

          <p
            style={{
              margin: "0",
              fontWeight: 700,
              ...styles.text_normal,
            }}
          >
            Borrowing Transaction
          </p>
        </div>

        {/* Yellow Capsule */}
        <div
          className="capsule"
          style={{
            background: "#FCF2E7",
            paddingTop: 50,
            margin: 30,
          }}
        >
          <div
            style={{
              display: "flex",
              justifyContent: "center",
              alignItems: "center",
              gap: "15px",
            }}
          >
            {/* Pending Req */}
            <div
              style={{
                display: "flex",
                width: "202px",
                height: "193px",
                padding: "25px 10px",
                flexDirection: "column",
                justifyContent: "space-between",
                alignItems: "center",
                borderRadius: "15px",
                background: "#FFF",
                boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
              }}
            >
              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_L,
                }}
              >
                {queries[1].data?.length || "Loading..."}
              </p>

              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_M,
                  fontWeight: "400",
                }}
              >
                Total Equipment
              </p>
            </div>
            <div
              style={{
                display: "flex",
                width: "40%",
                flexDirection: "column",
                justifyContent: "center",
                alignItems: "center",
                gap: "15px",
                alignSelf: "stretch",
              }}
            >
              <div
                style={{
                  display: "flex",
                  height: "100%",
                  width: "100%",
                  flexDirection: "column",
                  justifyContent: "center",
                  alignItems: "center",
                  alignSelf: "stretch",
                  borderRadius: "15px",
                  background: "#FFF",
                  boxShadow: "0px 4px 4px 0px rgba(0, 0, 0, 0.25)",
                }}
              >
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                  }}
                >
                  Available
                </p>
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: 0,
                  }}
                >
                  {queries[1].data?.filter(
                    (equipment) => equipment.status == "Available"
                  ).length || "Loading..."}
                </p>

                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                  }}
                >
                  Pending
                </p>
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: 0,
                  }}
                >
                  {queries[1].data?.filter(
                    (equipment) => equipment.status == "Pending"
                  ).length || 0}
                </p>

                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_S,
                    margin: "0",
                    fontWeight: "400",
                    color: "#a44141",
                  }}
                >
                  Broken
                </p>

                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_L,
                    margin: "0",
                    color: "#a44141",
                  }}
                >
                  {queries[1].data?.filter(
                    (equipment) => equipment.status == "Broken"
                  ).length || 0}
                </p>
              </div>
            </div>
          </div>
          <p
            style={{
              margin: "0",
              fontWeight: 700,
              ...styles.text_normal,
            }}
          >
            Equipment Tracking
          </p>
        </div>
      </div>
    </div>
  );
}
