import { useState } from "react";
import styles, { colors } from "../../styles";
import TextField from "@mui/material/TextField";
import InputAdornment from "@mui/material/InputAdornment";
import IconButton from "@mui/material/IconButton";
import Visibility from "@mui/icons-material/Visibility";
import VisibilityOff from "@mui/icons-material/VisibilityOff";
import Logo_dako from "../../assets/Logo_dako.png";
import { useNavigate } from "react-router-dom";
import { RegisterAPI } from "../API/API";
import { toast } from "react-toastify";
import {
  Radio,
  RadioGroup,
  FormControlLabel,
  FormControl,
  FormLabel,
} from "@mui/material";
export default function RegisterModal() {
  const navigate = useNavigate();
  const [showPassword, setShowPassword] = useState(false);

  const [user, setUser] = useState({
    first_name: "",
    last_name: "",
    username: "",
    email: "",
    course: "",
    password: "",
    confirm_password: "",
  });
  const [error, setError] = useState("");
  return (
    <>
      <div className="custom-scrollbar">
        <div
          style={{
            ...styles.flex_column,
            ...{
              alignItems: "center",
              justifyContent: "center",
              overflow: "auto",
              scrollbarWidth: "thin",
              WebkitOverflowScrolling: "touch",
            },
          }}
        >
          <img
            style={{ width: "10rem", height: "auto", alignSelf: "center" }}
            src={Logo_dako}
          />

          <p
            style={{
              ...styles.text_normal,
              fontSize: 24,
              margin: "0",
              marginTop: 15,
            }}
          >
            Create an Account
          </p>
          <p style={{ ...styles.text_normal, fontSize: 16, margin: "10" }}>
            Enter required fields
          </p>
        </div>

        <div style={{ flex: 1, backgroundColor: "pink", margin: "10px" }}>
          <p
            style={{
              ...styles.text_dark_red,
              ...styles.text_S,
              flex: 1,
              textAlign: "left",
              marginLeft: 15,
            }}
          >
            {error}
          </p>
        </div>

        <div
          style={{
            ...styles.flex_column,
            marginTop: 30,
            marginBottom: 55,
            marginInline: 10,
          }}
        >
          <TextField
            id="outlined-helperText"
            label="First Name"
            style={styles.input_form}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
              setUser({ ...user, first_name: e.target.value });
              setError("");
            }}
            value={user.first_name}
            placeholder={"Enter your first name"}
          />
          <TextField
            id="outlined-helperText"
            label="Last Name"
            style={styles.input_form}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
              setUser({ ...user, last_name: e.target.value })
            }
            value={user.last_name}
            placeholder={"Enter your last name"}
          />
          <TextField
            id="outlined-helperText"
            label="Email"
            style={styles.input_form}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
              setUser({ ...user, email: e.target.value })
            }
            value={user.email}
            placeholder={"Enter your email"}
          />

          <FormControl style={{ marginTop: "8px" }}>
            <FormLabel style={styles.text_dark} id="status-selection">
              Course
            </FormLabel>
            <RadioGroup
              aria-labelledby="demo-radio-buttons-group-label"
              value={user.course}
              defaultValue="BS Chemistry"
              name="radio-buttons-group"
              onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
                setUser({ ...user, course: e.target.value });
                setError("");
              }}
            >
              <div
                style={{
                  ...styles.flex_column,
                  ...{ overflowY: "scroll", maxHeight: "72px" },
                }}
              >
                <FormControlLabel
                  value="BS Chemistry"
                  control={<Radio />}
                  label="BS Chemistry"
                  style={styles.text_dark}
                />
                <FormControlLabel
                  value="BS Food Technology"
                  control={<Radio />}
                  label="BS Food Technology"
                  style={styles.text_dark}
                />
                <FormControlLabel
                  value="BS Applied Physics"
                  control={<Radio />}
                  label="BS Applied Physics"
                  style={styles.text_dark}
                />
                <FormControlLabel
                  value="BS Environmental Science"
                  control={<Radio />}
                  label="BS Environmental Science"
                  style={styles.text_dark}
                />
              </div>
            </RadioGroup>
          </FormControl>
          <TextField
            id="outlined-helperText"
            label="Username"
            style={styles.input_form}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
              setUser({ ...user, username: e.target.value });
              setError("");
            }}
            value={user.username}
            placeholder={"Enter username"}
          />
          <TextField
            id="outlined-helperText"
            type={showPassword ? "text" : "password"}
            style={styles.input_form}
            InputProps={{
              endAdornment: (
                <InputAdornment position="end">
                  <IconButton
                    aria-label="toggle password visibility"
                    onClick={() => setShowPassword(!showPassword)}
                    edge="end"
                  >
                    {showPassword ? <VisibilityOff /> : <Visibility />}
                  </IconButton>
                </InputAdornment>
              ),
            }}
            label="Password"
            placeholder={"Enter password"}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
              setUser({ ...user, password: e.target.value })
            }
            value={user.password}
          />
          <TextField
            id="outlined-helperText"
            type={showPassword ? "text" : "password"}
            style={styles.input_form}
            InputProps={{
              endAdornment: (
                <InputAdornment position="end">
                  <IconButton
                    aria-label="toggle password visibility"
                    onClick={() => setShowPassword(!showPassword)}
                    edge="end"
                  >
                    {showPassword ? <VisibilityOff /> : <Visibility />}
                  </IconButton>
                </InputAdornment>
              ),
            }}
            label="Confirm Password"
            placeholder={"Re-enter password"}
            onChange={(e: React.ChangeEvent<HTMLInputElement>) => {
              setUser({ ...user, confirm_password: e.target.value });
              setError("");
            }}
            value={user.confirm_password}
          />
        </div>

        <div
          style={{
            backgroundColor: colors.button_border,
            height: "2px",
            margin: "20px",
            marginBottom: "40px",
          }}
        />

        <div style={{ margin: "10px" }}>
          <button
            onClick={async () => {
              if (user.password !== user.confirm_password) {
                setError("Passwords do not match");
              } else {
                const status = await RegisterAPI(user);
                if (status[0]) {
                  setError(
                    "Registration successful. Please activate your account using the email provided"
                  );
                  toast("Registration successful", {
                    position: "top-right",
                    autoClose: 2000,
                    hideProgressBar: false,
                    closeOnClick: true,
                    pauseOnHover: true,
                    draggable: true,
                    progress: undefined,
                    theme: "light",
                  });
                  setTimeout(() => {
                    navigate(0);
                  }, 3000);
                  setUser({
                    first_name: "",
                    last_name: "",
                    username: "",
                    email: "",
                    password: "",
                    confirm_password: "",
                    course: "",
                  });
                } else {
                  setError(JSON.stringify(status[1]));
                }
              }
            }}
            style={{
              display: "flex",
              padding: "25px 38px",
              justifyContent: "center",
              alignItems: "center",
              background: "#FBB217",
              height: "40px",
              width: "100%",
            }}
          >
            Register
          </button>
        </div>
      </div>
    </>
  );
}
